%define upstream_name aws-cli

# Otherwise the expand doesn't work?
%global NAME %{upstream_name}-docs

Name:           aws-cli
Version:        2.17.55
Release:        %mkrel 1
Summary:        Universal Command Line Interface for Amazon Web Services (version 2)
License:        Apache License
Group:          Development/Tools
URL:            https://aws.amazon.com/cli
Source0:        https://github.com/aws/aws-cli/archive/%{version}/aws-cli-%{version}.tar.gz
BuildArch:      noarch
BuildRequires:  pyproject-rpm-macros
Requires:       python3-%{upstream_name} = %{version}

Provides:       bundled(python3dist(botocore)) = 2.0.0
Provides:       bundled(python3dist(s3transfer)) = 0.5.1

%description
The AWS Command Line Interface (CLI) is a unified tool to manage your AWS
services. With just one tool to download and configure, you can control
multiple AWS services from the command line and automate them through scripts.

The AWS CLI introduces a new set of simple file commands for efficient file
transfers to and from Amazon S3.

%package docs
Summary:        Additional documentation for %{upstream_name}
Group:          Documentation

%description docs
This package contains comprehensive CLI request/response examples for awscli
that can be viewed using e.g. 'aws ec2 run-instances help' when this package is
installed, but their absence doesn't impact the running of awscli.

Install this package if you need the examples, don't install it if you want to
reduce your image size but have the aws cli available.

%package -n python3-%{upstream_name}
Summary:        Universal Command Line Interface for Amazon Web Services (version 2)
Group:          Development/Python
License:        Apache License
BuildRequires:  pkgconfig(python3)
%{?python_provide:%python_provide python3-%{upstream_name}}

%description -n python3-%{upstream_name}
AWS CLI python libraries for Python 3.

%prep
%autosetup -p1

# fix permissions
find awscli/examples/ -type f -name '*.rst' -executable -exec chmod -x '{}' +

%generate_buildrequires
%pyproject_buildrequires

%build
%pyproject_wheel

# The man pages are 34M, and mainly duplicates the 'help' subcommands'
#pushd doc
#make man

%install
%pyproject_install

mkdir -p %{buildroot}%{_datadir}/bash-completion/completions
echo "complete -C aws_completer aws" > %{buildroot}%{_datadir}/bash-completion/completions/aws
rm -f %{buildroot}%{_bindir}/aws.cmd
rm -f %{buildroot}%{_bindir}/aws_*_completer*

# The examples make up ~2/3 of the size, no need to ship it with the code and duplicate it
rm -Rf %{buildroot}%{python3_sitelib}/awscli/examples
mkdir -p %{buildroot}%{_defaultdocdir}/%{expand:%{_docdir_fmt}}/examples
ln -s %{_defaultdocdir}/%{expand:%{_docdir_fmt}}/examples %{buildroot}%{python3_sitelib}/awscli/examples

%files
%license LICENSE.txt
%doc README.rst
%{_bindir}/aws
%{_bindir}/aws_completer
%{_datadir}/bash-completion/completions/aws
%dir %{_defaultdocdir}/%{expand:%{_docdir_fmt}}/examples

%files docs
%doc awscli/examples

%files -n python3-%{name}
%license LICENSE.txt
%doc README.rst
%{python3_sitelib}/awscli/
%{python3_sitelib}/awscli-%{version}.dist-info/


%changelog
* Fri Sep 20 2024 papoteur <papoteur> 2.17.55-1.mga10
+ Revision: 2099356
- version 2.17.55
- port to python 3.12
+ neoclust <neoclust>
- Rebuild against new python
+ daviddavid <daviddavid>
- rebuild for py3.12

* Wed Jun 21 2023 daviddavid <daviddavid> 2.12.1-2.mga9
+ Revision: 1962712
- relax dependencies

* Tue Jun 20 2023 daviddavid <daviddavid> 2.12.1-1.mga9
+ Revision: 1962701
- new version: 2.12.1
- switch to pyproject
- now use a bundled copy of botocore v2 and s3transfer v0.5.1

* Fri Jun 24 2022 papoteur <papoteur> 2.2.29-4.mga9
+ Revision: 1865959
- Mass Rebuild for dependencies

* Thu Mar 24 2022 umeabot <umeabot> 2.2.29-3.mga9
+ Revision: 1824072
- Mageia 9 Mass Rebuild

* Wed Mar 02 2022 mrambo3501 <mrambo3501> 2.2.29-2.mga9
+ Revision: 1787593
- rebuild for python-3.10

* Sat Aug 14 2021 wally <wally> 2.2.29-1.mga9
+ Revision: 1741302
- new version 2.2.29
- loosen all python reqs

* Fri Jan 01 2021 luigiwalser <luigiwalser> 2.1.15-1.mga9
+ Revision: 1667757
- 2.1.15
- 2.0.63

* Fri Aug 14 2020 neoclust <neoclust> 2.0.40-1.mga8
+ Revision: 1614057
- New version 2.0.40
+ buchan <buchan>
- Update to 2.0.8

* Sun Feb 16 2020 umeabot <umeabot> 1.16.254-2.mga8
+ Revision: 1534994
- Mageia 8 Mass Rebuild

* Tue Oct 08 2019 tv <tv> 1.16.254-1.mga8
+ Revision: 1450538
- new release
- bump rel

* Wed Sep 18 2019 tv <tv> 1.16.221-2.mga8
+ Revision: 1443655
- rebuild for python-3.8
- drop python2 subpkg

* Tue Aug 20 2019 buchan <buchan> 1.16.221-1.mga8
+ Revision: 1430679
- Update to 1.16.221

* Wed May 22 2019 buchan <buchan> 1.16.163-1.mga7
+ Revision: 1398911
- Upgrade to 1.16.163 matching a pull request fixing dependencies

* Sun Apr 21 2019 wally <wally> 1.16.114-1.mga7
+ Revision: 1394391
- new version 1.16.114
- switch to python3 by default
- add pyyaml patch from upstream pull request
- loosen botocore requires a bit

* Fri Jan 11 2019 tmb <tmb> 1.16.37-2.mga7
+ Revision: 1355146
- rebuild for python 3.7
+ pterjan <pterjan>
- Update to 1.16.37, unfortunately it only went from wanting pyyaml <= 3.12 to <= 3.13 and we have 4.1

* Thu Sep 20 2018 umeabot <umeabot> 1.15.35-2.mga7
+ Revision: 1277625
- Mageia 7 Mass Rebuild

* Sun Jun 10 2018 buchan <buchan> 1.15.35-1.mga7
+ Revision: 1236214
- New version 1.15.35

* Wed May 23 2018 buchan <buchan> 1.15.26-1.mga7
+ Revision: 1231926
- New version 1.15.26

* Tue Apr 17 2018 buchan <buchan> 1.15.4-1.mga7
+ Revision: 1219703
- New version 1.15.4

* Tue Apr 10 2018 buchan <buchan> 1.15.0-1.mga7
+ Revision: 1217274
- imported package aws-cli

